@@ -206,6 +206,7 @@ ischema_names = {
     'FLOAT': FLOAT,
     'TIME': TIME,
     'TIMESTAMP': TIMESTAMP,
+    'TIMESTMP': TIMESTAMP,
     'VARCHAR': VARCHAR,
     'LONGVARCHAR': LONGVARCHAR,
     'XML': XML,
@@ -408,9 +409,9 @@ class DB2Compiler(compiler.SQLCompiler):
             sql = '%s, ( ROW_NUMBER() OVER() ) AS "%s" FROM ( %s ) AS M' % (sql_sel, __rownum, sql_pri)
             sql = '%s FROM ( %s ) Z WHERE' % (sql_sel, sql)
 
-            if offset is not 0:
+            if offset != 0:
                 sql = '%s "%s" > %d' % (sql, __rownum, offset)
-            if offset is not 0 and limit is not None:
+            if offset != 0 and limit is not None:
                 sql = '%s AND ' % (sql)
             if limit is not None:
                 sql = '%s "%s" <= %d' % (sql, __rownum, offset + limit)
@@ -670,8 +671,10 @@ class DB2Dialect(default.DefaultDialect):
     supports_unicode_binds = False
     if SA_Version < [1, 4]:
         returns_unicode_strings = False
-    else:
+    elif SA_Version < [2, 0]:
         returns_unicode_strings = sa_types.String.RETURNS_CONDITIONAL
+    else:
+        returns_unicode_strings = True
     postfetch_lastrowid = True
     supports_sane_rowcount = True
     supports_sane_multi_rowcount = True
